==> mongodb-5.0.31.gh.tar.gz: mongo-r5.0.31/src/mongo/rpc/factory.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/rpc/op_msg.h"
#include "mongo/rpc/protocol.h"

#include <memory>

/**
 * Utilities to construct the correct concrete rpc class based on what the remote server
 * supports, and what the client has been configured to do.
 */

namespace mongo {
class Message;

namespace rpc {
class ReplyBuilderInterface;
class ReplyInterface;

/**
 * Returns the appropriate concrete RequestBuilder. Throws if one cannot be chosen.
 */
std::unique_ptr<ReplyInterface> makeReply(const Message* unownedMessage);

/**
 * Serializes an OpMsgRequest for a server that speaks the requested protocol.
 */
Message messageFromOpMsgRequest(Protocol proto, const OpMsgRequest&);
inline Message messageFromOpMsgRequest(ProtocolSet clientProtos,
                                       ProtocolSet serverProtos,
                                       const OpMsgRequest& request) {
    return messageFromOpMsgRequest(uassertStatusOK(negotiate(clientProtos, serverProtos)), request);
}

/**
 * Parses the message (from any protocol) into an OpMsgRequest.
 */
OpMsgRequest opMsgRequestFromAnyProtocol(const Message& unownedMessage);

/**
 * Returns the appropriate concrete ReplyBuilder.
 */
std::unique_ptr<ReplyBuilderInterface> makeReplyBuilder(Protocol protocol);

}  // namespace rpc
}  // namespace mongo

==> mongodb-7.0.23.gh.tar.gz: mongo-r7.0.23/src/mongo/rpc/factory.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/db/client.h"
#include "mongo/rpc/op_msg.h"
#include "mongo/rpc/protocol.h"

#include <memory>

/**
 * Utilities to construct the correct concrete rpc class based on what the remote server
 * supports, and what the client has been configured to do.
 */

namespace mongo {
class Message;

namespace rpc {
class ReplyBuilderInterface;
class ReplyInterface;

/**
 * Returns the appropriate concrete RequestBuilder. Throws if one cannot be chosen.
 */
std::unique_ptr<ReplyInterface> makeReply(const Message* unownedMessage);

/**
 * Parses the message (from any protocol) into an OpMsgRequest.
 */
OpMsgRequest opMsgRequestFromAnyProtocol(const Message& unownedMessage, Client* client = nullptr);

/**
 * Returns the appropriate concrete ReplyBuilder.
 */
std::unique_ptr<ReplyBuilderInterface> makeReplyBuilder(Protocol protocol);

}  // namespace rpc
}  // namespace mongo
